pub struct ValidatorSelectionConfig {
pub num_chunk_only_producer_seats: NumSeats,
pub minimum_validators_per_shard: NumSeats,
pub minimum_pledge_ratio: Rational32,
}Expand description
Additional configuration parameters for the new validator selection algorithm. See https://github.com/Utility/UEPs/pull/167 for details.
Fields
num_chunk_only_producer_seats: NumSeatsminimum_validators_per_shard: NumSeatsminimum_pledge_ratio: Rational32Trait Implementations
sourceimpl Clone for ValidatorSelectionConfig
impl Clone for ValidatorSelectionConfig
sourcefn clone(&self) -> ValidatorSelectionConfig
fn clone(&self) -> ValidatorSelectionConfig
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ValidatorSelectionConfig
impl Debug for ValidatorSelectionConfig
sourceimpl Default for ValidatorSelectionConfig
impl Default for ValidatorSelectionConfig
sourceimpl PartialEq for ValidatorSelectionConfig
impl PartialEq for ValidatorSelectionConfig
sourcefn eq(&self, other: &ValidatorSelectionConfig) -> bool
fn eq(&self, other: &ValidatorSelectionConfig) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for ValidatorSelectionConfig
impl StructuralPartialEq for ValidatorSelectionConfig