pub enum StateSyncDumpProgress {
AllDumped {
epoch_id: EpochId,
epoch_height: EpochHeight,
},
InProgress {
epoch_id: EpochId,
epoch_height: EpochHeight,
sync_hash: CryptoHash,
},
}Expand description
Represents the progress of dumps state of a shard.
Variants
AllDumped
Fields

epoch_id: EpochIdThe dumped state corresponds to the state at the beginning of the specified epoch.

epoch_height: EpochHeightRepresents two cases:
- An epoch dump is complete
- The node is running its first epoch and there is nothing to dump.
InProgress
Fields

epoch_id: EpochIdThe dumped state corresponds to the state at the beginning of the specified epoch.

epoch_height: EpochHeight
sync_hash: CryptoHashBlock hash of the first block of the epoch. The dumped state corresponds to the state before applying this block.
Represents the case of an epoch being partially dumped.