pub struct ExecutionOutcome {
pub logs: Vec<LogEntry>,
pub receipt_ids: Vec<CryptoHash>,
pub gas_burnt: Gas,
pub compute_usage: Option<Compute>,
pub tokens_burnt: Balance,
pub executor_id: AccountId,
pub status: ExecutionStatus,
pub metadata: ExecutionMetadata,
}Expand description
Execution outcome for one signed transaction or one receipt.
Fields
logs: Vec<LogEntry>Logs from this transaction or receipt.
receipt_ids: Vec<CryptoHash>Receipt IDs generated by this transaction or receipt.
gas_burnt: GasThe amount of the gas burnt by the given transaction or receipt.
compute_usage: Option<Compute>The amount of compute time spent by the given transaction or receipt.
tokens_burnt: BalanceThe amount of tokens burnt corresponding to the burnt gas amount.
This value doesn’t always equal to the gas_burnt multiplied by the gas price, because
the prepaid gas price might be lower than the actual gas price and it creates a deficit.
executor_id: AccountIdThe id of the account on which the execution happens. For transaction this is signer_id, for receipt this is receiver_id.
status: ExecutionStatusExecution status. Contains the result in case of successful execution. NOTE: Should be the latest field since it contains unparsable by light client ExecutionStatus::Failure
metadata: ExecutionMetadataExecution metadata, versioned