pub struct PartialExecutionOutcome {
pub receipt_ids: Vec<CryptoHash>,
pub gas_burnt: Gas,
pub tokens_burnt: Balance,
pub executor_id: AccountId,
pub status: PartialExecutionStatus,
}Expand description
ExecutionOutcome for proof. Excludes logs and metadata
Fields
receipt_ids: Vec<CryptoHash>gas_burnt: Gastokens_burnt: Balanceexecutor_id: AccountIdstatus: PartialExecutionStatusTrait Implementations
sourceimpl BorshDeserialize for PartialExecutionOutcome
impl BorshDeserialize for PartialExecutionOutcome
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl Clone for PartialExecutionOutcome
impl Clone for PartialExecutionOutcome
sourcefn clone(&self) -> PartialExecutionOutcome
fn clone(&self) -> PartialExecutionOutcome
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl From<&ExecutionOutcome> for PartialExecutionOutcome
impl From<&ExecutionOutcome> for PartialExecutionOutcome
sourcefn from(outcome: &ExecutionOutcome) -> Self
fn from(outcome: &ExecutionOutcome) -> Self
Converts to this type from the input type.
sourceimpl From<&ExecutionOutcomeView> for PartialExecutionOutcome
impl From<&ExecutionOutcomeView> for PartialExecutionOutcome
sourcefn from(outcome: &ExecutionOutcomeView) -> Self
fn from(outcome: &ExecutionOutcomeView) -> Self
Converts to this type from the input type.
sourceimpl PartialEq for PartialExecutionOutcome
impl PartialEq for PartialExecutionOutcome
sourcefn eq(&self, other: &PartialExecutionOutcome) -> bool
fn eq(&self, other: &PartialExecutionOutcome) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl StructuralPartialEq for PartialExecutionOutcome