Struct unc_primitives::types::StateChangesForBlock
source · pub struct StateChangesForBlock {
pub block_hash: CryptoHash,
pub state_changes: Vec<StateChangesForShard>,
}Expand description
State changes for a single block. Expects that a shard is present at most once in the list of state changes.
Fields
block_hash: CryptoHashstate_changes: Vec<StateChangesForShard>Trait Implementations
sourceimpl BorshDeserialize for StateChangesForBlock
impl BorshDeserialize for StateChangesForBlock
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,