Struct unc_primitives::types::StateChangesForBlockRange
source · pub struct StateChangesForBlockRange {
pub blocks: Vec<StateChangesForBlock>,
}Expand description
State changes for a range of blocks. Expects that a block is present at most once in the list.
Fields
blocks: Vec<StateChangesForBlock>Trait Implementations
sourceimpl BorshDeserialize for StateChangesForBlockRange
impl BorshDeserialize for StateChangesForBlockRange
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,