Type Alias unc_primitives::types::Gas
source · pub type Gas = u64;Expand description
Reexport primitive types Gas is a type for storing amount of gas.
pub type Gas = u64;Reexport primitive types Gas is a type for storing amount of gas.