Module version

Module version 

Macros

checked_feature
unc_primitives_core re-exports

Structs

Version
Data structure for semver version and github tag or commit.

Enums

ProtocolFeature
New Protocol features should go here. Features are guarded by their corresponding feature flag. For example, if we have ProtocolFeature::EVM and a corresponding feature flag evm, it will look like

Constants

CORRECT_RANDOM_VALUE_PROTOCOL_VERSION
CREATE_HASH_PROTOCOL_VERSION
Updates the way receipt ID, data ID and random seeds are constructed.
CREATE_RECEIPT_ID_SWITCH_TO_CURRENT_BLOCK_VERSION
Updates the way receipt ID is constructed to use current block hash instead of last block hash
DELETE_KEY_STORAGE_USAGE_PROTOCOL_VERSION
Fix the storage usage of the delete key action.
ENABLE_INFLATION_PROTOCOL_VERSION
The protocol version that enables reward on mainnet.
MIN_GAS_PRICE_UIP_92
Minimum gas price proposed in UIP 92 and the associated protocol version
MIN_GAS_PRICE_UIP_92_FIX
Minimum gas price proposed in UIP 92 (fixed) and the associated protocol version
MIN_PROTOCOL_VERSION_UIP_92
MIN_PROTOCOL_VERSION_UIP_92_FIX
PEER_MIN_ALLOWED_PROTOCOL_VERSION
Both, outgoing and incoming tcp connections to peers, will be rejected if peer's protocol version is lower than this.
PROTOCOL_UPGRADE_SCHEDULE
The points in time after which the voting for the latest protocol version should start.
PROTOCOL_VERSION
Largest protocol version supported by the current binary.
SHARD_CHUNK_HEADER_UPGRADE_VERSION
UPGRADABILITY_FIX_PROTOCOL_VERSION
Fix upgrade to use the latest voted protocol version instead of the current epoch protocol version when there is no new change in protocol version.

Functions

get_protocol_version
Gives new clients an option to upgrade without announcing that they support the new version. This gives non-validator nodes time to upgrade. See https://github.com/Utility/UEPs/issues/205

Type Aliases

ProtocolVersion