Module unc_primitives::views

source ·
This module defines “stable” internal API to view internal data using view_client.

These types should only change when we cannot avoid this. Thus, when the counterpart internal type gets changed, the view should preserve the old shape and only re-map the necessary bits from the source structure in the relevant From<SourceStruct> impl.

Modules

Structs

Enums

Type Aliases