Macros
- checked_
feature - unc_primitives_core re-exports
Structs
- Version
- Data structure for semver version and github tag or commit.
Enums
- Protocol
Feature - New Protocol features should go here. Features are guarded by their corresponding feature flag.
For example, if we have
ProtocolFeature::EVMand a corresponding feature flagevm, it will look like
Constants
- CORRECT_
RANDOM_ VALUE_ PROTOCOL_ VERSION - CREATE_
HASH_ PROTOCOL_ VERSION - Updates the way receipt ID, data ID and random seeds are constructed.
- CREATE_
RECEIPT_ ID_ SWITCH_ TO_ CURRENT_ BLOCK_ VERSION - Updates the way receipt ID is constructed to use current block hash instead of last block hash
- DELETE_
KEY_ STORAGE_ USAGE_ PROTOCOL_ VERSION - Fix the storage usage of the delete key action.
- ENABLE_
INFLATION_ PROTOCOL_ VERSION - The protocol version that enables reward on mainnet.
- MIN_
GAS_ PRICE_ UIP_ 92 - Minimum gas price proposed in UIP 92 and the associated protocol version
- MIN_
GAS_ PRICE_ UIP_ 92_ FIX - Minimum gas price proposed in UIP 92 (fixed) and the associated protocol version
- MIN_
PROTOCOL_ VERSION_ UIP_ 92 - MIN_
PROTOCOL_ VERSION_ UIP_ 92_ FIX - PEER_
MIN_ ALLOWED_ PROTOCOL_ VERSION - Both, outgoing and incoming tcp connections to peers, will be rejected if
peer'sprotocol version is lower than this. - PROTOCOL_
UPGRADE_ SCHEDULE - The points in time after which the voting for the latest protocol version should start.
- PROTOCOL_
VERSION - Largest protocol version supported by the current binary.
- SHARD_
CHUNK_ HEADER_ UPGRADE_ VERSION - UPGRADABILITY_
FIX_ PROTOCOL_ VERSION - Fix upgrade to use the latest voted protocol version instead of the current epoch protocol version when there is no new change in protocol version.
Functions
- get_
protocol_ version - Gives new clients an option to upgrade without announcing that they support the new version. This gives non-validator nodes time to upgrade. See https://github.com/Utility/UEPs/issues/205