Module unc_primitives::views
source · Expand description
This module defines “stable” internal API to view internal data using view_client.
These types should only change when we cannot avoid this. Thus, when the counterpart internal
type gets changed, the view should preserve the old shape and only re-map the necessary bits
from the source structure in the relevant From<SourceStruct> impl.
Modules
Structs
- A view of the account
- A view of the contract code.
- Information about this epoch validators and next epoch validators
- Execution outcome of the transaction and all of subsequent the receipts. Could be not finalised yet
- Final execution outcome of the transaction and all of subsequent the receipts. Also includes the generated receipt.
- Information about a Producer: its account name, peer_id and a list of connected peers that the node can use to send message for this producer.
- Contains the split storage information.
- Item of the state, key and value are serialized in base64 and proof for inclusion of given state item.
- State for the view call.
Enums
- See crate::types::StateChangeCause for details.
- It is a serializable view of
StateChangeKind. - It is a serializable view of
StateChangesRequest.
Type Aliases
- Maintenance windows view are a vector of maintenance window.